@@ -3,16 +3,15 @@
 #ifndef PARSE_UTILS_H
 #define PARSE_UTILS_H
 
-void rm_head_ws(const char *line, char **clean_line);
-int only_ws(const char *line);
 int yes_or_no(const char *line);
 int set_yes_or_no(const char *line, int *set);
-int check_interface(const char *interface);
+int check_interface(const char *_interface);
 int check_ip(const char *ip);
 int check_list(const char **list, size_t len);
 long parse_port(const char *line, int *valid);
 unsigned long parse_ulong(const char *line, int *valid);
 int set_servers(const char *line, char ***hostname, uint16_t **port, 
 		size_t *hosts);
+int split_conf_row(char *line, char **name, char **value);
 
 #endif /* PARSE_UTILS_H */
