@@ -5,6 +5,7 @@
 
 #include <pftp_settings.h>
 
-int sethost(const char *site, pftp_settings_t conf);
+int sethost(const char *site, int save_pass, int clr_pass, 
+	    pftp_settings_t conf);
 
 #endif /* SETHOSTS_H */
