@@ -1,16 +1,31 @@
 /* -*- pftp-c -*- */
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
+#endif
+#if HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#if HAVE_STDIO_H
+# include <stdio.h>
+#endif
+#if HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+#if HAVE_STRING_H
+# include <string.h>
+#endif
+#if HAVE_FNMATCH_H
+# include <fnmatch.h>
+#endif
+#if HAVE_INTTYPES_H
+# include <inttypes.h>
+#endif
+#if HAVE_TIME_H
+# include <time.h>
 #endif
-#include <stdlib.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <string.h>
-#include <fnmatch.h>
-#include <inttypes.h>
 
 #ifdef WITH_DMALLOC
-#include <dmalloc.h>
+# include <dmalloc.h>
 #endif
 
 #include "patternmatch.h"
@@ -19,7 +34,7 @@
 //returnerar 0 om ngon match och 1 om ingen match
 int listfnmatch(char *str, char **p, size_t nr)
 {
-    int I = 0;
+    size_t I = 0;
     while (I < nr) {
 	if(!fnmatch(p[I], str,0))
 	    return 0;
@@ -30,7 +45,7 @@ int listfnmatch(char *str, char **p, size_t nr)
 
 void priolist(pftp_directory_t *dir, char **prio, size_t p)
 {
-    int i, j, nr = 0;
+    size_t i, j, nr = 0;
     pftp_file_t tmp;
 
     for (i = 0; i < p; i++) {
