@@ -2,11 +2,18 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
-
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <stdio.h>
+#if HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#if HAVE_STRING_H
+# include <string.h>
+#endif
+#if HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+#if HAVE_STDIO_H
+# include <stdio.h>
+#endif
 #ifdef WITH_DMALLOC
 #include <dmalloc.h>
 #endif
@@ -15,10 +22,16 @@
 
 const char *yesno(int val)
 {
-    if (val)
+    switch(val)
+    {
+    case 1:
 	return "yes";
-    else
-	return "no";
+    case 0:
+ 	return "no";
+    default:
+    case -1:
+	return "";
+    }
 }
 
 void longval(char **str, long val)
